@@ -1,3 +1,3 @@
 from loop import instance
 from event import EventEmitter
-from net import Socket
+from net import Socket, Server
